==> tomee-project-8.0.3-source-release.zip: tomee-project-8.0.3/container/openejb-core/src/test/java/org/apache/openejb/cdi/PostConstructOnPrivateMethodTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.cdi;

import org.apache.openejb.junit.ApplicationComposer;
import org.apache.openejb.testing.Module;
import org.junit.Test;
import org.junit.runner.RunWith;

import javax.annotation.PostConstruct;
import javax.inject.Inject;

import static org.junit.Assert.assertEquals;

@RunWith(ApplicationComposer.class)
public class PostConstructOnPrivateMethodTest {
    @Module
    public Class<?>[] cdi() {
        return new Class<?>[]{CdiPrivatePostConstruct.class};
    }

    @Inject
    private CdiPrivatePostConstruct bean;

    @Test
    public void test() {
        assertEquals("bar", new CdiPrivatePostConstruct().getValue()); // not managed by cdi so no @PostConstruct
        assertEquals("foo", bean.getValue());
    }

    public static class CdiPrivatePostConstruct {
        private String value = "bar";

        @PostConstruct
        private void init() {
            value = "foo";
        }

        public String getValue() {
            return value;
        }
    }
}

==> tomee-project-10.1.3-source-release.zip: tomee-project-10.1.3/container/openejb-core/src/test/java/org/apache/openejb/cdi/PostConstructOnPrivateMethodTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.cdi;

import org.apache.openejb.junit.ApplicationComposer;
import org.apache.openejb.testing.Module;
import org.junit.Test;
import org.junit.runner.RunWith;

import jakarta.annotation.PostConstruct;
import jakarta.inject.Inject;

import static org.junit.Assert.assertEquals;

@RunWith(ApplicationComposer.class)
public class PostConstructOnPrivateMethodTest {
    @Module
    public Class<?>[] cdi() {
        return new Class<?>[]{CdiPrivatePostConstruct.class};
    }

    @Inject
    private CdiPrivatePostConstruct bean;

    @Test
    public void test() {
        assertEquals("bar", new CdiPrivatePostConstruct().getValue()); // not managed by cdi so no @PostConstruct
        assertEquals("foo", bean.getValue());
    }

    public static class CdiPrivatePostConstruct {
        private String value = "bar";

        @PostConstruct
        private void init() {
            value = "foo";
        }

        public String getValue() {
            return value;
        }
    }
}
